@@ -651,7 +651,6 @@ class Bot(GroupMixin, discord.Client):
         for name, member in members:
             # register commands the cog has
             if isinstance(member, Command):
-                member.instance = cog
                 if member.parent is None:
                     self.add_command(member)
                 continue
@@ -699,7 +698,6 @@ class Bot(GroupMixin, discord.Client):
         for name, member in members:
             # remove commands the cog has
             if isinstance(member, Command):
-                member.instance = None
                 if member.parent is None:
                     self.remove_command(member.name)
                 continue
