@@ -32,7 +32,6 @@ import logging
 import weakref
 import datetime
 from email.utils import parsedate_to_datetime
-from random import randint as random_integer
 
 log = logging.getLogger(__name__)
 
@@ -85,18 +84,6 @@ class MaybeUnlock:
 class HTTPClient:
     """Represents an HTTP client sending HTTP requests to the Discord API."""
 
-    BASE          = 'https://discordapp.com'
-    API_BASE      = BASE     + '/api/v6'
-    GATEWAY       = API_BASE + '/gateway'
-    USERS         = API_BASE + '/users'
-    ME            = USERS    + '/@me'
-    REGISTER      = API_BASE + '/auth/register'
-    LOGIN         = API_BASE + '/auth/login'
-    LOGOUT        = API_BASE + '/auth/logout'
-    GUILDS        = API_BASE + '/guilds'
-    CHANNELS      = API_BASE + '/channels'
-    APPLICATIONS  = API_BASE + '/oauth2/applications'
-
     SUCCESS_LOG = '{method} {url} has received {text}'
     REQUEST_LOG = '{method} {url} with {json} has returned {status}'
 
@@ -105,7 +92,8 @@ class HTTPClient:
         self.connector = connector
         self.session = aiohttp.ClientSession(connector=connector, loop=self.loop)
         self._locks = weakref.WeakValueDictionary()
-        self._global_lock = asyncio.Lock(loop=self.loop)
+        self._global_over = asyncio.Event(loop=self.loop)
+        self._global_over.set()
         self.token = None
         self.bot_token = False
 
@@ -139,9 +127,9 @@ class HTTPClient:
 
         kwargs['headers'] = headers
 
-        if self._global_lock.locked():
+        if not self._global_over.is_set():
             # wait until the global lock is complete
-            yield from self._global_lock
+            yield from self._global_over.wait()
 
         yield from lock
         with MaybeUnlock(lock) as maybe_lock:
@@ -154,7 +142,7 @@ class HTTPClient:
 
                     # check if we have rate limit header information
                     remaining = r.headers.get('X-Ratelimit-Remaining')
-                    if remaining == '0':
+                    if remaining == '0' and r.status != 429:
                         # we've depleted our current bucket
                         if header_bypass_delay is None:
                             now = parsedate_to_datetime(r.headers['Date'])
@@ -185,15 +173,16 @@ class HTTPClient:
                         is_global = data.get('global', False)
                         if is_global:
                             log.info('Global rate limit has been hit. Retrying in {:.2} seconds.'.format(retry_after))
-                            # acquire the global lock and block all processing
-                            yield from self._global_lock
+                            self._global_over.clear()
 
                         yield from asyncio.sleep(retry_after, loop=self.loop)
+                        log.debug('Done sleeping for the rate limit. Retrying...')
 
                         # release the global lock now that the
                         # global rate limit has passed
                         if is_global:
-                            self._global_lock.release()
+                            self._global_over.set()
+                            log.debug('Global rate limit is now over.')
 
                         continue
 
@@ -291,9 +280,7 @@ class HTTPClient:
 
     def send_message(self, channel_id, content, *, guild_id=None, tts=False, embed=None):
         r = Route('POST', '/channels/{channel_id}/messages', channel_id=channel_id)
-        payload = {
-            'nonce': random_integer(-2**63, 2**63 - 1)
-        }
+        payload = {}
 
         if content:
             payload['content'] = content
@@ -380,7 +367,6 @@ class HTTPClient:
         return self.request(r)
 
     def logs_from(self, channel_id, limit, before=None, after=None, around=None):
-        url = '{0.CHANNELS}/{1}/messages'.format(self, channel_id)
         params = {
             'limit': limit
         }
@@ -403,7 +389,7 @@ class HTTPClient:
                             channel_id=channel_id, message_id=message_id))
 
     def pins_from(self, channel_id):
-        return self.request(Route('GET', '/channels/{channel_id}/pins/', channel_id=channel_id))
+        return self.request(Route('GET', '/channels/{channel_id}/pins', channel_id=channel_id))
 
     # Member management
 
@@ -463,13 +449,11 @@ class HTTPClient:
 
     def edit_member(self, guild_id, user_id, **fields):
         r = Route('PATCH', '/guilds/{guild_id}/members/{user_id}', guild_id=guild_id, user_id=user_id)
-        return self.request(r, json=fields, bucket=bucket)
+        return self.request(r, json=fields)
 
     # Channel management
 
     def edit_channel(self, channel_id, **options):
-        url = '{0.CHANNELS}/{1}'.format(self, channel_id)
-
         valid_keys = ('name', 'topic', 'bitrate', 'user_limit', 'position')
         payload = {
             k: v for k, v in options.items() if k in valid_keys
@@ -477,6 +461,10 @@ class HTTPClient:
 
         return self.request(Route('PATCH', '/channels/{channel_id}', channel_id=channel_id), json=payload)
 
+    def move_channel_position(self, guild_id, positions):
+        r = Route('PATCH', '/guilds/{guild_id}/channels', guild_id=guild_id)
+        return self.request(r, json=positions)
+
     def create_channel(self, guild_id, name, channe_type, permission_overwrites=None):
         payload = {
             'name': name,
@@ -559,7 +547,8 @@ class HTTPClient:
         payload = {
             'max_age': options.get('max_age', 0),
             'max_uses': options.get('max_uses', 0),
-            'temporary': options.get('temporary', False)
+            'temporary': options.get('temporary', False),
+            'unique': options.get('unique', True)
         }
 
         return self.request(r, json=payload)
@@ -597,9 +586,13 @@ class HTTPClient:
         return self.edit_member(guild_id=guild_id, user_id=user_id, roles=role_ids)
 
     def create_role(self, guild_id):
-        r = Route('POST', '/guilds/{guild_id}/roles/', guild_id=guild_id)
+        r = Route('POST', '/guilds/{guild_id}/roles', guild_id=guild_id)
         return self.request(r)
 
+    def move_role_position(self, guild_id, positions):
+        r = Route('PATCH', '/guilds/{guild_id}/roles', guild_id=guild_id)
+        return self.request(r, json=positions)
+
     def add_role(self, guild_id, user_id, role_id):
         r = Route('PUT', '/guilds/{guild_id}/members/{user_id}/roles/{role_id}',
                   guild_id=guild_id, user_id=user_id, role_id=role_id)
@@ -632,7 +625,7 @@ class HTTPClient:
     # Misc
 
     def application_info(self):
-        return self.request(Route('GET', '/oauth/applications/@me'))
+        return self.request(Route('GET', '/oauth2/applications/@me'))
 
     @asyncio.coroutine
     def get_gateway(self):
