@@ -213,7 +213,7 @@ class ConnectionState:
         servers = self._ready_state.servers
         for guild in guilds:
             server = self._add_server_from_data(guild)
-            if not self.is_bot or server.large:
+            if (not self.is_bot and not server.unavailable) or server.large:
                 servers.append(server)
 
         for pm in data.get('private_channels'):
@@ -410,7 +410,7 @@ class ConnectionState:
             if role is not None:
                 roles.append(role)
 
-        data['roles'] = sorted(roles, key=lambda r: int(r.id))
+        data['roles'] = sorted(roles)
         return Member(server=server, **data)
 
     def parse_guild_member_add(self, data):
@@ -463,7 +463,7 @@ class ConnectionState:
                     member.roles.append(role)
 
             # sort the roles by ID since they can be "randomised"
-            member.roles.sort(key=lambda r: int(r.id))
+            member.roles.sort()
             self.dispatch('member_update', old_member, member)
 
     def parse_guild_emojis_update(self, data):
@@ -487,8 +487,8 @@ class ConnectionState:
 
     @asyncio.coroutine
     def _chunk_and_dispatch(self, server, unavailable):
-        yield from self.chunker(server)
         chunks = list(self.chunks_needed(server))
+        yield from self.chunker(server)
         if chunks:
             try:
                 yield from asyncio.wait(chunks, timeout=len(chunks), loop=self.loop)
@@ -689,6 +689,8 @@ class ConnectionState:
 
     def _get_member(self, channel, id):
         if channel.is_private:
+            if id == self.user.id:
+                return self.user
             return utils.get(channel.recipients, id=id)
         else:
             return channel.server.get_member(id)
